@@ -2,7 +2,6 @@ import html
 from typing import Any
 from typing import Dict
 from typing import Iterable
-from typing import Iterator
 from typing import List
 from typing import TextIO
 
@@ -27,10 +26,11 @@ class TableReporter:
     @classmethod
     def from_snapshot(
         cls,
-        allocations: Iterator[AllocationRecord],
+        allocations: Iterable[AllocationRecord],
         *,
         memory_records: Iterable[MemorySnapshot],
         native_traces: bool,
+        **kwargs: Any,
     ) -> "TableReporter":
         result = []
         for record in allocations:
@@ -62,13 +62,22 @@ class TableReporter:
         outfile: TextIO,
         metadata: Metadata,
         show_memory_leaks: bool,
+        merge_threads: bool,
+        inverted: bool,
     ) -> None:
+        if not merge_threads:
+            raise NotImplementedError("TableReporter only supports merged threads.")
+        if inverted:
+            raise NotImplementedError(
+                "TableReporter does not support inverted argument"
+            )
         html_code = render_report(
             kind="table",
             data=self.data,
             metadata=metadata,
             memory_records=self.memory_records,
             show_memory_leaks=show_memory_leaks,
-            merge_threads=True,
+            merge_threads=merge_threads,
+            inverted=inverted,
         )
         print(html_code, file=outfile)
